<?php

/**
* Principal Controller
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Conversation_Builder
* @subpackage 	Alexandria_Conversation_Builder/admin/controllers
*/

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class MainController {

	static function intiBuilder($lang) {

		global $sitepress;

	    // lang from your javascript
		$lang_code = $lang != '' ? $lang : 'es';

	    // switch to the desired language
		$sitepress->switch_lang($lang_code);

		$data = [
			'interlocutors' => []
		];

		$args = array(  
			'post_type' => 'interlocutors',
			'post_status' => 'publish',
			'posts_per_page' => -1,
			'suppress_filters' => 0,
			'orderby' => 'title', 
			'order' => 'ASC'
		);

		$data['interlocutors'] = get_posts($args);

		do_action('alexandria_show_main_template', 'steps_container', $data);
		
	} // end index


	static function getConversationMetadata($lang) {

		global $sitepress;

	    // lang from your javascript
		$lang_code = $lang != '' ? $lang : 'es';

	    // switch to the desired language
		$sitepress->switch_lang($lang_code);

		$interlocutor_id = $_POST['interlocutor'];
		$situation_id = $_POST['situation'];
		$tono_id = $_POST['tono'];

		$data = [];

		$args = array(  
			'post_type' => 'conversations',
			'post_status' => 'publish',
			'numberposts' => 1,
			'suppress_filters' => 0,
			'meta_query' => array(
				'relation' => 'AND',
				array(
					'key'   => '_interlocutor',
					'value' => intval($interlocutor_id),
					'meta_compare'	=> '='
				),
				array(
					'key'   => '_situation',
					'value' => intval($situation_id),
					'meta_compare'	=> '='
				),
				array(
					'key'   => '_tono',
					'value' => intval($tono_id),
					'meta_compare'	=> '='
				)
			)
		);

		$conversation = get_posts($args);

		if(isset($conversation)) {

			$metadata_array = array(

				'objectives' => get_post(get_post_meta( $conversation[0]->ID, '_objective', true )),
				'soliloquios' => [],
				'conclusions' => [],
				'decisions' => [],
				'expect_results' => [],

				'strong_questions' => [],
				'relevance' => get_post(get_post_meta( $conversation[0]->ID, '_relevance', true )),
				'arguments' => [],
				'viable_minimal' => [],
				'comments' => [],
				'builder_examples' => []
			);

			$soliloquios = get_post_meta( $conversation[0]->ID, '_soliloquios', true );
			$conclusions = get_post_meta( $conversation[0]->ID, '_conclusions', true );
			$decisions = get_post_meta( $conversation[0]->ID, '_decisions', true );
			$expect_results = get_post_meta( $conversation[0]->ID, '_expect_results', true );

			$strong_questions = get_post_meta( $conversation[0]->ID, '_strong_questions', true );
			$arguments = get_post_meta( $conversation[0]->ID, '_arguments', true );
			$viable_minimal = get_post_meta( $conversation[0]->ID, '_viable_minimal', true );
			$comments = get_post_meta( $conversation[0]->ID, '_conversation_comments', true );

			$examples = get_post_meta( $conversation[0]->ID, '_examples', true );


			foreach ($soliloquios as $index => $value) {
				$metadata_array['soliloquios'][$index] = get_post($value);
			}

			foreach ($conclusions as $index => $value) {
				$metadata_array['conclusions'][$index] = get_post($value);
			}

			foreach ($decisions as $index => $value) {
				$metadata_array['decisions'][$index] = get_post($value);
			}

			foreach ($expect_results as $index => $value) {
				$metadata_array['expect_results'][$index] = get_post($value);
			}

			foreach ($arguments as $index => $value) {
				$argument = get_post($value);
				$metadata_array['arguments'][$index] = $argument;
				$metadata_array['arguments'][$index]->content = apply_filters( 'the_content', $argument->post_content );
			}
			
			foreach ($viable_minimal as $index => $value) {
				$metadata_array['viable_minimal'][$index] = get_post($value);
			}

			foreach ($comments as $index => $value) {
				$metadata_array['comments'][$index] = get_post($value);
			}

			foreach ($examples as $index => $value) {
				$post = get_post($value);
				$metadata_array['examples'][$index] = get_post($value);
				$metadata_array['examples'][$index]->content = apply_filters( 'the_content', $post->post_content );
			}

			foreach ($strong_questions as $index => $value) {

				$post = get_post($value);
				$terms = get_the_terms($post->ID, 'strong_questions-categories');
				$term = array_pop($terms);

				$metadata_array['strong_questions'][$index] = $post;
				$metadata_array['strong_questions'][$index]->category = $term;
				$metadata_array['strong_questions'][$index]->video_type = get_post_meta($post->ID,'video_type', true);
				$metadata_array['strong_questions'][$index]->video_id = get_post_meta($post->ID,'video_id', true);
				$metadata_array['strong_questions'][$index]->video_id = get_post_meta($post->ID,'video_url', true);
			}

			$data['conversation'] = $conversation[0];
			$data['metadata'] = $metadata_array;
		}

		echo json_encode($data);
		exit;
	}

}